#!/usr/bin/env python

# Usage Example
from enstools.feature.pipeline import FeaturePipeline
from enstools.feature.identification.aew_vortices import AEWVortexIdentification
from datetime import timedelta, datetime
from enstools.feature.identification._proto_gen import african_easterly_waves_pb2
from os.path import expanduser, join
from enstools.feature.util.graph import DataGraph
import enstools.feature.identification.aew_vortices.configuration as cfg
import os, sys, glob, shutil
from enstools.feature.util.data_utils import get_subset_by_description
import xarray as xr
xr.set_options(keep_attrs=True)
import numpy as np
from pprint import pprint

pipeline = FeaturePipeline(african_easterly_waves_pb2, processing_mode='2d')

# in_files_all_cv_data = cfg.cv_data_ex

in_file = cfg.in_data
in_desc = cfg.in_wts
pipeline.set_data_path(in_file)

# init AEWIdentification strategy, can take different parameters
i_strat = AEWVortexIdentification()
# t_strat = SomeTracking()

pipeline.set_identification_strategy(i_strat)
# pipeline.set_tracking_strategy(t_strat)

# execute pipeline
pipeline.execute()

od = pipeline.get_object_desc()

all_tracks = []
for set_id, trackable_set in enumerate(od.sets):

    # generate graph out of tracked data
    g = DataGraph(trackable_set, t_strat)

    # generate single tracks from tracked data
    # returns list of tracks, also gets added to object description. Also if apply_filter, keep_track can be implemented
    g.generate_tracks(apply_filter=True) # add tracks to OD, applies filtering TODO tracks not in desc.
    tracks = g.set_desc.tracks

    # parents of a node: track.get_parents(track.graph.edges[0].parent)
    # children of a node: track.get_children(track.graph.edges[0].parent)

    # plot tracks

    for track_id, track in enumerate(tracks):
        plot_track(track, "track" + "{:03d}".format(set_id) + "_" + "{:03d}".format(track_id))

    ds = pipeline.get_data()
    ds_set = get_subset_by_description(ds, trackable_set, '2d')
    # plot differences (passed filtering / did not pass)
    # plot_differences(g, tracks) TODO need to fix if we want this

    # for track_id, track in enumerate(tracks):
    #     plot_track(track, "track" + str(track_id))

    all_tracks.extend(tracks)
# ds_set = get_subset_by_description(ds, trackable_set, '2d')
    
ds = pipeline.get_data()

# plot kitweather mode
# if len(sys.argv) > 1 and sys.argv[1] == '-kw':
#     plot_kw(all_tracks, ds=ds, tp=rain_ds.tp, plot_prefix=(plot_dir + run + '/' + plot_file_prefix), ens_mode=ens_mode) # TODO need g?



# no out dataset here.
pipeline.save_result(description_type='json', description_path=cfg.out_json_path) #, dataset_path=out_dataset_path) # dataset_path=out_dataset_path,
